==> webkit2gtk_2.20.5.orig.tar.xz: webkitgtk-2.20.5/Source/WebKit/Shared/WebSQLiteDatabaseTracker.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebSQLiteDatabaseTracker_h
#define WebSQLiteDatabaseTracker_h

#include <WebCore/SQLiteDatabaseTrackerClient.h>
#include <pal/HysteresisActivity.h>
#include <wtf/Noncopyable.h>

namespace WebKit {

class ChildProcess;
class NetworkProcess;
class WebProcess;

class WebSQLiteDatabaseTracker : public WebCore::SQLiteDatabaseTrackerClient {
    WTF_MAKE_NONCOPYABLE(WebSQLiteDatabaseTracker)
public:
    explicit WebSQLiteDatabaseTracker(NetworkProcess&);
    explicit WebSQLiteDatabaseTracker(WebProcess&);

    // WebCore::SQLiteDatabaseTrackerClient
    void willBeginFirstTransaction() override;
    void didFinishLastTransaction() override;

private:
    void hysteresisUpdated(PAL::HysteresisState);

    ChildProcess& m_process;
    PAL::HysteresisActivity m_hysteresis;
    enum class ChildProcessType { Network, WebContent };
    ChildProcessType m_childProcessType;
};

} // namespace WebKit

#endif // WebSQLiteDatabaseTracker_h

==> webkit2gtk_2.24.2.orig.tar.xz: webkitgtk-2.24.2/Source/WebKit/Shared/WebSQLiteDatabaseTracker.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/SQLiteDatabaseTrackerClient.h>
#include <pal/HysteresisActivity.h>
#include <wtf/Noncopyable.h>

namespace WebKit {

class NetworkProcess;

class WebSQLiteDatabaseTracker : public WebCore::SQLiteDatabaseTrackerClient {
    WTF_MAKE_NONCOPYABLE(WebSQLiteDatabaseTracker)
public:
    explicit WebSQLiteDatabaseTracker(NetworkProcess&);

    // WebCore::SQLiteDatabaseTrackerClient
    void willBeginFirstTransaction() override;
    void didFinishLastTransaction() override;

private:
    void hysteresisUpdated(PAL::HysteresisState);

    NetworkProcess& m_process;
    PAL::HysteresisActivity m_hysteresis;
};

} // namespace WebKit
